# 在 CasaOS 部署 AstrBot

## 安装 CasaOS

```bash
curl -fsSL https://get.casaos.io | sudo bash
```

## 添加 CasaOS-AppStore-Play 应用商店源

![image](https://files.astrbot.app/docs/source/images/casaos/image.png)

点击 `更多应用`，然后输入:

```txt
https://play.cuse.eu.org/Cp0204-AppStore-Play.zip
```

并添加，等待添加完成。

如果您的网络环境在国内，请先搜索并添加 `dkTurbo`，否则可能无法拉取 AstrBot 镜像。

![image](https://files.astrbot.app/docs/source/images/casaos/image-1.png)

输入 `Astrbot` 即可找到 AstrBot。

![image](https://files.astrbot.app/docs/source/images/casaos/image-2.png)

点击图标（不是安装按钮），然后悬浮到`安装`按钮上，点击自定义安装。

![image](https://files.astrbot.app/docs/source/images/casaos/image-3.png)

在网络一栏选择 `host`。

![image](https://files.astrbot.app/docs/source/images/casaos/image-4.png)

然后点击`安装`开始安装。

安装完成后，主界面会出现 AstrBot APP，点击即可打开管理面板。